#Load data
treexant <- read.csv("treexants.csv", header=T)
nestxant <- read.csv("nestxants.csv", header=T)

##############################################################
########## Figure 1. alpha, beta, gamma diversity ############
##############################################################

##load data---------------------------------------------------------------------------
setwd("C://Users//nicho//Research Projects//Current projects//PNG Felling Projects")
treexant <- read.csv("treexants.csv", header=T)
treexant$`ANON.002`<- treexant$`ANON.002`+ treexant$`ANON.004`#update, these species have been synonymised

######### Accumulation curves with iNEXT and ggplot2 #########
##############################################################

##load packages-----------------------------------------------------------------------
library(iNEXT)
library(ggplot2)
library(ggbeeswarm)

##data as lists-------------------------------------------------------------------------
full.list <-vector("list")
full.list$Wanang <- (t(treexant[263:734,2:170]))
full.list$Numba <- (t(treexant[1:262,2:170]))
full.list$Yawan <- (t(treexant[735:1254,2:170]))

#full.list$All <- (t(treexant[,2:170]))

full.list$Wanang[full.list$Wanang>1] <-1
full.list$Numba[full.list$Numba>1] <-1
full.list$Yawan[full.list$Yawan>1] <-1
#full.list$All[full.list$All>1] <-1

#plot species accumulation curves with inext--------------------------------------------
out.all <- iNEXT(full.list, datatype="incidence_raw", endpoint=600, nboot=999)
gamma.plot <- (ggiNEXT(out.all)+
                 theme_bw(base_size = 18))+
  theme(legend.position="none")+
  #theme(legend.position="bottom",
  #legend.title=element_blank())+
  scale_colour_manual(values=c("#D55E00", "#009E73","purple")) +
  scale_fill_manual(values=c("#D55E00", "#009E73","purple"))+
  scale_x_continuous(name ="N. trees sampled", limits=c(0,605))+
  scale_y_continuous(name ="Cumulative n. ant species", limits=c(0,150))

#----------------------------------------------------------------------------------------
######## Species richnesss per tree at different elevations###############
##########################################################################

#Calculate number of species per tree----------------------------------------------------
test<-treexant[,2:170]
test[test>0]<-1
sp.per.tree <- rowSums(test, na.rm = T)
treexant$sp.per.tree <- sp.per.tree

#relevel
levels(treexant$Forest)<- c("900","200","1800")
treexant$Forest<-relevel(treexant$Forest,"200")


#plot per tree species richness vs elevation---------------------------------------------------------
alphaplot2 <- ggplot(treexant, aes(x = Forest, y = sp.per.tree, color=Forest))+
  #geom_violin (aes(fill=Forest), varwidth = TRUE, cex=2, alpha=0.4)+
  geom_quasirandom(data = treexant, aes(x = Forest, y = sp.per.tree), varwidth = TRUE, cex=2, alpha=0.4)+
  #geom_jitter(data = treexant, aes(x=Forest, y=sp.per.tree), position=position_jitter(0.3), cex=1, alpha=0.4)+
  stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median,geom = "crossbar", width = 0.5, col="black")+
  theme_bw()+
  theme(legend.position="none")+
  scale_color_brewer(palette="Dark2") +
  scale_x_discrete(name="Elevation (m.a.s.l)")+
  scale_y_continuous(name="Number of species per tree")

#----------------------------------------------------------------------------------------
##### Beta diversity (Sorensen aka bray ) per tree with median bar  #####
#########################################################################


##load packages
library(vegan)
library(vipor)

#Select communities
midcom<-treexant[which(treexant$Forest=="900"),2:170]
dim(midcom)
hicom<-treexant[which(treexant$Forest=="1800"),2:170]
dim(hicom)
lowcom<-treexant[which(treexant$Forest=="200"),2:170]
dim(lowcom)

levels(treexant$Subplot)
wacom<-treexant[which(treexant$Subplot=="WP_SUBPLOT_A"),2:170]
wbcom<-treexant[which(treexant$Subplot=="WP_SUBPLOT_B"),2:170]
nacom<-treexant[which(treexant$Subplot=="NP_SUBPLOT_A"),2:170]
yacom<-treexant[which(treexant$Subplot=="YP_SUBPLOT_A"),2:170]
yccom<-treexant[which(treexant$Subplot=="YP_SUBPLOT_C"),2:170]

#function to remove absent species 
fc.makeitsmall<-function(data.source)
{
  for ( i in 1:ncol(data.source))
  {
    data.source[,i]<-as.double(data.source[,i])
  }
  df.res<-data.source[rowSums(data.source)>0,colSums(data.source)>0]
  return (df.res)
}

#remove absent species from distance matrices
lowcom.s <-fc.makeitsmall(lowcom)
midcom.s <-fc.makeitsmall(midcom)
hicom.s <-fc.makeitsmall(hicom)

wacom.s <-fc.makeitsmall(wacom)
dim(wacom.s)
wbcom.s<-fc.makeitsmall(wbcom)
nacom.s<-fc.makeitsmall(nacom)
yacom.s<-fc.makeitsmall(yacom)
yccom.s<-fc.makeitsmall(yccom)

#compute sorensen (binary coverts to presence-absence, thus not computing bray-curtis but SORENSEN)
lo <- as.matrix(vegdist(lowcom.s, method="bray", binary=TRUE, na.rm = TRUE))
mi <- as.matrix(vegdist(midcom.s, method="bray", binary=TRUE, na.rm = TRUE))
hi <- as.matrix(vegdist(hicom.s, method="bray", binary=TRUE, na.rm = TRUE))

wa <- as.matrix(vegdist(wacom.s, method="bray", binary=TRUE, na.rm = TRUE))
wb <- as.matrix(vegdist(wbcom.s, method="bray", binary=TRUE, na.rm = TRUE))
na <- as.matrix(vegdist(nacom.s, method="bray", binary=TRUE, na.rm = TRUE))
ya <- as.matrix(vegdist(yacom.s, method="bray", binary=TRUE, na.rm = TRUE))
yc <- as.matrix(vegdist(yccom.s, method="bray", binary=TRUE, na.rm = TRUE))

#generate dataframe of pairwise sorensen
lo.names <- t(combn(colnames(lo), 2))
mi.names <- t(combn(colnames(mi), 2))
hi.names <- t(combn(colnames(hi), 2))

wa.names <- t(combn(colnames(wa), 2))
wb.names <- t(combn(colnames(wb), 2))
na.names <- t(combn(colnames(na), 2))
ya.names <- t(combn(colnames(ya), 2))
yc.names <- t(combn(colnames(yc), 2))

lo.df <- data.frame(lo.names, dist=lo[lo.names])
mi.df <- data.frame(mi.names, dist=mi[mi.names])
hi.df <- data.frame(hi.names, dist=hi[hi.names])

wa.df <- data.frame(wa.names, dist=wa[wa.names])
wb.df <- data.frame(wb.names, dist=wb[wb.names])
na.df <- data.frame(na.names, dist=na[na.names])
ya.df <- data.frame(ya.names, dist=ya[ya.names])
yc.df <- data.frame(yc.names, dist=yc[yc.names])

#sorensen whole elevation # Used for plots
dim(lo.df)
dim(mi.df)
dim(hi.df)
elev.sorensen <- rbind(lo.df,mi.df,hi.df)
elev.sorensen$Elevation <- as.factor(c(rep("200",52975),rep("900", 24976), rep("1800",23871)))
elev.sorensen$Elevation <- factor(elev.sorensen$Elevation, levels = c("200", "900", "1800"))

# sorensens within subplot# Used for stats
dim(wa.df)
dim(wb.df)
dim(na.df)
dim(ya.df)
dim(yc.df)
full.sorensen <- rbind(wa.df,wb.df,na.df,ya.df,yc.df)# sorensens within subplot
full.sorensen$Subplot <- as.factor(c(rep("WA",11325),rep("WB",15225),rep("NA",24976),rep("YA", 5886),rep("YC",5995)))
full.sorensen$Elevation <- as.factor(c(rep("200",26550),rep("900", 24976), rep("1800",11881)))
full.sorensen$Elevation <- factor(full.sorensen$Elevation, levels = c("200", "900", "1800"))

#aggregate to get means for each tree
mean.sor  <- aggregate(dist ~ X1 + Elevation, data=elev.sorensen, mean) # Use for plots
mean.sor2 <- aggregate(dist ~ X1 + Elevation+Subplot, data=full.sorensen, mean) 


### Mean Sorensen value for each tree (all pairwise combinations within elevations)
sorensen.means <- ggplot(mean.sor, aes(x = Elevation, y = dist,  col=Elevation))+
  geom_quasirandom(data = mean.sor, aes(x = Elevation, y = dist), varwidth = TRUE, cex=2, alpha=0.4)+
  stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median,geom = "crossbar", width = 0.5, col="black")+
  theme_bw()+
  theme(legend.position="none")+
  scale_color_brewer(palette="Dark2") +
  scale_x_discrete(name="Elevation (m.a.s.l)")+
  scale_y_continuous(name="Mean Sorensen dissimilarity", breaks=c(0,0.25,0.5,0.75,1.0))+
  expand_limits(y = c(0, 1))


###############   Multiplot function (R cookbook) #############################
###############################################################################

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


#################### Plot all 3 figures ###############
########################################################
multiplot( gamma.plot,
           alphaplot2,
           sorensen.means,
           cols=3)



#GLM beta diversity
library(lme4)
b0<-glm(dist ~ +1, full.sorensen,family="quasibinomial")
b3<-glm(dist ~ Elevation, full.sorensen,family="quasibinomial")
anova(b0,b3, test = "Chisq")
summary (b3)


