#load data
nestxant <- read.csv("nestxants.csv", header=T)
head(nestxant)
library(ggplot2)
library(plyr) 
library(RColorBrewer)
library(reshape2)

#### NEST SIZE WITH ELEVATION #####

## Changes in nest size over elevation for most common shared species
#prop nest size by forest

#all species together
nest.size <- table(nestxant$NestSize, nestxant$Forest)
nest.size1 <- melt(nest.size)
names(nest.size1)<- c("Size", "Elevation", "Value")
nest.size1$Elevation <- c(rep("900",4),rep("200",4),rep("1800",4))
nest.size1$Elevation <- factor(nest.size1$Elevation, levels = c("200", "900", "1800"))
nest.size1$Size<-factor(nest.size1$Size, levels=c("4","3","2","1"))

nest.size.plot <- ggplot(nest.size1, aes(x=Elevation, y=Value, fill=Size)) + 
  geom_bar(position = "fill",stat="identity")+
  scale_fill_manual(values=c("#b30000", "#e34a33","#fc8d59","#fdcc8a"))+
  scale_x_discrete(name="Elevation")+
  scale_y_continuous(name="Proportion of observed nests") +
  theme_bw()

#individual species
#para003
nsizepara3 <- nestxant[which(nestxant$PARA.003==1),c("Forest","Subplot","NestSize")]
para3size<-data.frame(table(nsizepara3$NestSize, nsizepara3$Forest))
para3size$Var2<-c(rep("900",4),rep("200",4),rep("1800",4))
para3size$Var2<-factor(para3size$Var2, levels = c("200", "900", "1800"))
para3size$Var1<-factor(para3size$Var1, levels=c("4","3","2","1"))
#para1
nsizepara1 <- nestxant[which(nestxant$PARA.001==1),c("Forest","Subplot","NestSize")]
para1size<-data.frame(table(nsizepara1$NestSize, nsizepara1$Forest))
para1size$Var2<-c(rep("900",4),rep("200",4),rep("1800",4))
para1size$Var2<-factor(para1size$Var2, levels = c("200", "900", "1800"))
para1size$Var1<-factor(para1size$Var1, levels=c("4","3","2","1"))
#poly4
nsizepoly4 <- nestxant[which(nestxant$POLY.004==1),c("Forest","Subplot","NestSize")]
poly4size<-data.frame(table(nsizepoly4$NestSize, nsizepoly4$Forest))
poly4size$Var2<-c(rep("900",2),rep("200",2),rep("1800",2))
poly4size$Var2<-factor(poly4size$Var2, levels = c("200", "900", "1800"))
poly4size$Var1<-factor(poly4size$Var1, levels=c("4","3","2","1"))
#phei4
nsizephei4 <- nestxant[which(nestxant$PHEI.004==1),c("Forest","Subplot","NestSize")]
phei4size<-data.frame(table(nsizephei4$NestSize, nsizephei4$Forest))
phei4size$Var2<-c(rep("900",4),rep("200",4),rep("1800",4))
phei4size$Var2<-factor(phei4size$Var2, levels = c("200", "900", "1800"))
phei4size$Var1<-factor(phei4size$Var1, levels=c("4","3","2","1"))
#anon2
nestxant$ANON.002 <- nestxant$ANON.002+nestxant$ANON.004
nsizeanon2 <- nestxant[which(nestxant$ANON.002==1),c("Forest","Subplot","NestSize")]
anon2size<-data.frame(table(nsizeanon2$NestSize, nsizeanon2$Forest))
anon2size$Var2<-c(rep("900",4),rep("200",4),rep("1800",4))
anon2size$Var2<-factor(anon2size$Var2, levels = c("200", "900", "1800"))
anon2size$Var1<-factor(anon2size$Var1, levels=c("4","3","2","1"))

#All species to one df
top.species <- rbind(anon2size,phei4size,para1size,para3size,poly4size)
top.species$Species <- c(rep("ANON002",12),rep("PHEI004",12),rep("PARA001",12),rep("PARA003",12),rep("POLY004",6))
nest.size1$Species <- "ALL"
names(top.species) <- names(nest.size1)
all.species <- rbind(nest.size1,top.species)

#Plot Nest size ~ Elevation for all species and separate species in panels
ggplot(all.species, aes(x=Elevation, y=Value, fill=Size)) + 
  geom_bar(position = "fill",stat="identity")+
  scale_fill_manual(values=c("#b30000", "#e34a33","#fc8d59","#fdcc8a"))+
  facet_grid(~Species)+
  scale_x_discrete(name="Elevation (m above sea level)")+
  scale_y_continuous(name="Nest Proportion") +
  theme_light()


##### NEST DIVERSITY WITH ELEVATION #####
#proportion barplot of nesting habitat by forest type
nest1 <- table(nestxant$NestSite, nestxant$Forest)
nestpr<-data.frame(nest1[,2]/sum(nest1[,2]))
nestpr$Numba <- (nest1[,1]/sum(nest1[,1]))
nestpr$Yawan <- (nest1[,3]/sum(nest1[,3]))
nestpr<-data.frame(nestpr)
names(nestpr) <- c("Wanang.200m", "Numba.900m","Yawan.1800m")
rownames(nestpr)
nestpr<-as.matrix(nestpr)

nestpr.0<-as.data.frame(nestpr)
df.nest.a<- as.data.frame(nestpr.0$Wanang.200m)
df.nest.b<- as.data.frame(nestpr.0$Numba.900m)
df.nest.c<- as.data.frame(nestpr.0$Yawan.1800m)
names(df.nest.a)<-"Proportion"
names(df.nest.b)<-"Proportion"
names(df.nest.c)<-"Proportion"
df.nest<- rbind(df.nest.a,df.nest.b,df.nest.c)
df.nest$NestType<- rep(row.names(nestpr),3)
df.nest$Elev <- c(rep("200m",12), rep("900m",12),rep("1800m",12))
df.nest$Elev<-as.factor(df.nest$Elev)

neworder <- c("200m", "900m","1800m")
df.nest <-arrange(transform(df.nest,Elev=factor(Elev,levels=neworder)),Elev)
getPalette = colorRampPalette(brewer.pal(9, "Greens"))
Palette.1<-getPalette(12)
names(Palette.1) <- unique(df.nest$NestType)

ggplot(df.nest, aes(y=Proportion,x=NestType))+
  geom_bar(stat="identity",aes(fill=NestType))+
  #scale_fill_manual(values = Palette.1)+
  theme_bw()+
  theme()+ #axis.text.x =  element_text(angle = -90, hjust = 1),axis.text.y =  element_text(angle = -90, hjust = 1)
  ylab("Proportion of observed ant nests")+
  xlab("")+
  guides(fill=FALSE)+
  facet_wrap(~Elev)+
  coord_flip()

#species differences over elevation?
nsiteanon2 <- nestxant[which(nestxant$ANON.002==1),c("Forest","Subplot","NestSite")]
anon2site <- data.frame(table(nsiteanon2$NestSite, nsiteanon2$Forest))



########### PUT IT TO THE TEST ##########
###Contingency tables & Chisq

# Does the nest size differ with elevation?
nest.size <- table(nestxant$NestSize, nestxant$Forest)
chisq.test(nest.size)#X-squared = 297.64, df = 6, p-value < 2.2e-16 # YES

# Does the proportion of different nest sites change with elevation?
nest.site <- table(nestxant$NestSite, nestxant$Forest)
chisq.test(nest.site) #X-squared = 644.48, df = 22, p-value < 2.2e-16 #Chi-squared approximation may be incorrect # non-normal distrib.
fisher.test(nest.site, simulate.p.value=TRUE)#table too large so pval simulation required # YES, P<0.001
