#----------------------------------fig 4---------------------------------
## import packages
library(iNEXT)
library(ggplot2)


### Load data of number of nest sites per tree
nestdiv<-read.csv("nestsitediv.csv", header = T)#doesn't include trees without nests
head(nestdiv)
nestdiv$Elevation <- c(rep("900",224),rep("200",326),rep("1800",219))


t1<-droplevels(treexant$TreeNo[which(treexant$N.nest>0)])
identical(t1,nestdiv$TreeNo)# check the order before adding subplot&DBH
nestdiv$Subplot <- treexant$Subplot[which(treexant$N.nest>0)]
nestdiv$DBH <- treexant$DBH[which(treexant$N.nest>0)]
nestdiv$N.nests <- treexant$N.nest[which(treexant$N.nest>0)]

head(nestdiv)
summary(nestdiv)
names(treexant)

#df of trees with 0 nests
empties<-treexant[which(treexant$sp.per.tree==0),c(171:173,178,179)]
head(empties)

empties$nest.site.div<-0
head(empties)
head(nestdiv)
empties <- empties[,c(1,6,2,3,5,4)]
names(empties)<-names(nestdiv)

nestdiv1<-rbind(nestdiv,empties)
nestdiv1$Elevation <- as.ordered(nestdiv1$Elevation)
head(nestdiv1)
View(nestdiv1)

# DBH vs sprich , n. nest, nest diversity-----------------------------------------
library(ggplot2)

treexant$Elevation <- treexant$Forest 
levels(treexant$Elevation)
levels(nestdiv1$Elevation)

# treexant$Elevation<-relevel(treexant$Elevation,ref="200")
nestdiv1$Elevation <-factor(nestdiv1$Elevation, levels =c("200", "900", "1800"),ordered=F)

#palette <- c("#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
dev.off()
sprichDBHplot <- ggplot(treexant,aes(x=DBH, y=sp.per.tree,color=Elevation))+ 
  geom_point(aes(shape=Elevation),alpha=1)+
  theme_bw()+
  scale_color_brewer(palette="Dark2") +
  #scale_colour_manual(values=c("#E69F00","#009E73","#56B4E9")) + 
  scale_shape_manual(values=c(17,16,22))+
  theme(legend.position="bottom")+
  scale_y_continuous(name="N. species", limits=c(0,18))+
  scale_x_continuous(name="DBH (cm)")+
  geom_smooth(method=glm,   # Add linear regression lines
              se=T,    # add shaded confidence region
              fullrange=F, alpha=0.2, method.args = list(family = "poisson"))

nestdivplot <- ggplot(nestdiv1,aes(x=DBH, y= Nest.site.div,color=Elevation))+ 
  geom_point(aes(shape=Elevation))+
  theme_bw()+
  scale_color_brewer(palette="Dark2") +
  #scale_colour_manual(values=c("#56B4E9","#009E73","#E69F00")) + 
  scale_shape_manual(values=c(17,16,22))+
  theme(legend.position="bottom")+
  scale_y_continuous(name="N. nest types", limits=c(0,5))+
  scale_x_continuous(name="DBH (cm)")+
  geom_smooth(method=glm,   # Add fitted
              se=T,    # add shaded confidence region
              fullrange=F, alpha=0.2, method.args = list(family = "poisson"))

nestnumplot <- ggplot(nestdiv1,aes(x=DBH, y= N.nests,color=Elevation))+ 
  geom_point(aes(shape=Elevation))+
  theme_bw()+
  scale_color_brewer(palette="Dark2") +
  #scale_colour_manual(values=c("#56B4E9","#009E73","#E69F00")) + 
  scale_shape_manual(values=c(17,16,22))+
  theme(legend.position="bottom")+
  scale_y_continuous(name="N. nests", limits=c(0,23))+
  scale_x_continuous(name="DBH (cm)")+
  geom_smooth(method=glm,   # Add fitted
              se=T,    # add shaded confidence region
              fullrange=F, alpha=0.2, method.args = list(family = "poisson"))




multiplot(
  sprichDBHplot ,
  nestnumplot,
  nestdivplot,
  cols = 3)


#------------------------------------------------------------------------------
#glmmTMB - zero inflated models
#Species richness
library(lme4)
library(glmmTMB)

n.mod0 <- glmmTMB(sp.per.tree ~ (+ 1) + (1|Subplot), data=treexant, family=genpois(link = "log")) 
n.mod1 <- glmmTMB(sp.per.tree ~ DBH + (1|Subplot), data=treexant, family=genpois(link = "log"))
anova(n.mod0,n.mod1, test="Chisq")

n.mod2 <- glmmTMB(sp.per.tree ~ Forest + (1|Subplot), data=treexant, family=genpois(link = "log"))
anova(n.mod0,n.mod2, test="Chisq")

n.mod3 <- glmmTMB(sp.per.tree ~ DBH + Forest + (1|Subplot), data=treexant, family=genpois(link = "log"))
anova(n.mod1,n.mod3, test="Chisq")

n.mod4 <- glmmTMB(sp.per.tree ~ DBH * Forest + (1|Subplot), data=treexant, family=genpois(link = "log"))
anova(n.mod3,n.mod4, test="Chisq")


# Nest abundance
nn.mod0 <- glmmTMB(N.nests ~ (+ 1) + (1|Subplot), data=nestdiv1, family=genpois(link = "log")) 
nn.mod1 <- glmmTMB(N.nests ~ DBH + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nn.mod0,nn.mod1, test="Chisq")

nn.mod2 <- glmmTMB(N.nests ~ Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nn.mod0,nn.mod2, test="Chisq")

nn.mod3 <- glmmTMB(N.nests ~ DBH + Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nn.mod1,nn.mod3, test="Chisq")

nn.mod4 <- glmmTMB(N.nests ~ DBH * Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nn.mod3,nn.mod4, test="Chisq")



# nest diversity
names(nestdiv1)
nnn.mod0 <- glmmTMB(Nest.site.div ~ (+ 1) + (1|Subplot), data=nestdiv1, family=genpois(link = "log")) 
nnn.mod1 <- glmmTMB(Nest.site.div ~ DBH + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nnn.mod0,nnn.mod1, test="Chisq")

nnn.mod2 <- glmmTMB(Nest.site.div ~ Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nnn.mod0,nnn.mod2, test="Chisq")

nnn.mod3 <- glmmTMB(Nest.site.div ~ DBH + Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nnn.mod1,nnn.mod3, test="Chisq")

nnn.mod4 <- glmmTMB(Nest.site.div ~ DBH * Elevation + (1|Subplot), data=nestdiv1, family=genpois(link = "log"))
anova(nnn.mod3,nnn.mod4, test="Chisq")


